@@ -39,6 +39,11 @@ public:
         std::cout << "~new_style_class." << std::endl;
     }
 
+    long cxx_method( long a, long b )
+    {
+        return a * b + 3;
+    }
+
     static void init_type(void)
     {
         behaviors().name( "new_style_class" );
@@ -89,7 +94,6 @@ public:
     {
         std::cout << "new_style_class_func_noargs_raise_exception Called." << std::endl;
         throw Py::RuntimeError( "its an error" );
-        return Py::None();
     }
     PYCXX_NOARGS_METHOD_DECL( new_style_class, new_style_class_func_noargs_raise_exception )
 
@@ -189,12 +193,16 @@ public:
         old_style_class::init_type();
         new_style_class::init_type();
 
+        add_noargs_method( "mod_func_noargs", &simple_module::mod_func_noargs, "documentation for mod_func_noargs()" );
+        add_varargs_method( "mod_func_varargs", &simple_module::mod_func_varargs, "documentation for mod_func_varargs()" );
+        add_keyword_method( "mod_func_keyword", &simple_module::mod_func_keyword, "documentation for mod_func_keyword()" );
+
         add_varargs_method("old_style_class", &simple_module::factory_old_style_class, "documentation for old_style_class()");
-        add_keyword_method("func", &simple_module::func, "documentation for func()");
         add_keyword_method("make_instance", &simple_module::make_instance, "documentation for make_instance()");
 
         add_keyword_method("decode_test", &simple_module::decode_test, "documentation for decode_test()");
         add_keyword_method("encode_test", &simple_module::encode_test, "documentation for encode_test()");
+        add_keyword_method("derived_class_test", &simple_module::derived_class_test, "documentation for derived_class_test()");
 
         // after initialize the moduleDictionary will exist
         initialize( "documentation for the simple module" );
@@ -209,21 +217,46 @@ public:
     {}
 
 private:
-    Py::Object decode_test( const Py::Tuple &args, const Py::Dict &kwds )
+    Py::Object decode_test( const Py::Tuple &args, const Py::Dict &/*kwds*/ )
     {
         Py::String s( args[0] );
         return s.decode("utf-8");
     }
 
-    Py::Object encode_test( const Py::Tuple &args, const Py::Dict &kwds )
+    Py::Object encode_test( const Py::Tuple &args, const Py::Dict &/*kwds*/ )
     {
         Py::String s( args[0] );
         return s.encode("utf-8");
     }
 
-    Py::Object func( const Py::Tuple &args, const Py::Dict &kwds )
+    Py::Object derived_class_test( const Py::Tuple &args, const Py::Dict &/*kwds*/ )
     {
-        std::cout << "func Called with " << args.length() << " normal arguments." << std::endl;
+        Py::PythonClassObject<new_style_class> py_nsc( args[0] );
+        new_style_class *cxx_nsc = py_nsc.getCxxObject();
+
+        Py::Long a( args[1] );
+        Py::Long b( args[2] );
+
+        long result = cxx_nsc->cxx_method( a, b );
+
+        return Py::Long( result );
+    }
+
+    Py::Object mod_func_noargs()
+    {
+        std::cout << "mod_func_noargs Called." << std::endl;
+        return Py::None();
+    }
+
+    Py::Object mod_func_varargs( const Py::Tuple &args )
+    {
+        std::cout << "mod_func_varargs Called with " << args.length() << " normal arguments." << std::endl;
+        return Py::None();
+    }
+
+    Py::Object mod_func_keyword( const Py::Tuple &args, const Py::Dict &kwds )
+    {
+        std::cout << "mod_func_varargs Called with " << args.length() << " normal arguments." << std::endl;
         Py::List names( kwds.keys() );
         std::cout << "and with " << names.length() << " keyword arguments:" << std::endl;
         for( Py::List::size_type i=0; i< names.length(); i++ )
@@ -270,7 +303,7 @@ private:
     }
 
 
-    Py::Object factory_old_style_class( const Py::Tuple &rargs )
+    Py::Object factory_old_style_class( const Py::Tuple &/*args*/ )
     {
         Py::Object obj = Py::asObject( new old_style_class );
         return obj;
@@ -283,7 +316,7 @@ private:
 #define EXPORT_SYMBOL
 #endif
 
-#if defined( PY3 )
+#if PY_MAJOR_VERSION == 3
 static simple_module *simple;
 
 extern "C" EXPORT_SYMBOL PyObject *PyInit_simple()
